@@ -330,6 +330,42 @@ go_string_append_c_n (GString *target, char c, gsize n)
 	memset (target->str + len, c, n);
 }
 
+void
+go_string_replace (GString *target,
+		   gsize pos, gssize oldlen,
+		   const char *txt, gssize newlen)
+{
+	gsize cplen;
+
+	g_return_if_fail (target != NULL);
+	g_return_if_fail (pos >= 0);
+	g_return_if_fail (pos < target->len);
+
+	if (oldlen < 0)
+		oldlen = target->len - pos;
+	if (newlen < 0)
+		newlen = strlen (txt);
+
+	cplen = MIN (oldlen, newlen);
+	memcpy (target->str + pos, txt, cplen);
+
+	pos += cplen;
+	oldlen -= cplen;
+	txt += cplen;
+	newlen -= cplen;
+
+	/*
+	 * At least one of oldlen and newlen is zero now.  We could call
+	 * both erase and insert unconditionally, but erase does not appear
+	 * to handle zero length efficiently.
+	 */
+
+	if (oldlen > 0)
+		g_string_erase (target, pos, oldlen);
+	else if (newlen > 0)
+		g_string_insert_len (target, pos, txt, newlen);
+}
+
 /* ------------------------------------------------------------------------- */
 
 /**
@@ -994,7 +1030,7 @@ go_parse_key_value (const char *options,
 			       g_unichar_isalnum (g_utf8_get_char (options)))
 				options = g_utf8_next_char (options);
 			g_string_append_len (sname, p, options - p);
-			if (p == options) 
+			if (p == options)
 				goto syntax;
 		}
 
